@@ -78,10 +78,10 @@ DOBISS_TYPE_FLAG = 206
 
 
 class DobissEntity:
-    """ a generic Dobiss Entity, can be a light, switch, sensor, etc... """
+    """a generic Dobiss Entity, can be a light, switch, sensor, etc..."""
 
     def __init__(self, dobiss, data, groupname):
-        """ Initialize a DobissLight """
+        """Initialize a DobissLight"""
         self._json = data
         self._attributes = dict()
         self._attributes["dobiss_group"] = groupname
@@ -158,7 +158,7 @@ class DobissEntity:
 
     @property
     def value(self):
-        """Return the value of the entity.	"""
+        """Return the value of the entity."""
         return self._value
 
     @property
@@ -204,11 +204,17 @@ class DobissEntity:
         and you want to update the internal value"""
         attributes = self._attributes
         if self.address == DOBISS_TEMPERATURE:
-            val = float(status["temp"])
+            try:
+                val = float(status["temp"])
+            except ValueError:
+                val = None
             attributes = self._attributes.copy()
             attributes.update(status)
         else:
-            val = int(status)
+            if type(status) == dict:
+                val = int(status["status"])
+            else:
+                val = int(status)
         if force or self._value != val or self._attributes != attributes:
             self._value = val
             self._attributes = attributes
@@ -249,7 +255,7 @@ class DobissEntity:
 
 
 class DobissOutput(DobissEntity):
-    """ a generic Dobiss Output, can be a light, switch, etc... """
+    """a generic Dobiss Output, can be a light, switch, etc..."""
 
     async def toggle(self):
         if self.is_on:
@@ -276,27 +282,27 @@ class DobissOutput(DobissEntity):
 
 
 class DobissLight(DobissOutput):
-    """ a dobiss light object, can be dimmable or not """
+    """a dobiss light object, can be dimmable or not"""
 
 
 class DobissAnalogOutput(DobissOutput):
-    """ a dobiss light object, can be dimmable or not """
+    """a dobiss light object, can be dimmable or not"""
 
 
 class DobissSwitch(DobissOutput):
-    """ a dobiss switch, can be up/down switch, door switch, etc... """
+    """a dobiss switch, can be up/down switch, door switch, etc..."""
 
 
 class DobissScenario(DobissSwitch):
-    """ a dobiss scenario """
+    """a dobiss scenario"""
 
 
 class DobissAutomation(DobissSwitch):
-    """ a dobiss automation """
+    """a dobiss automation"""
 
 
 class DobissFlag(DobissSwitch):
-    """ a dobiss flag """
+    """a dobiss flag"""
 
 
 class DobissSensor(DobissEntity):
@@ -316,7 +322,7 @@ class DobissSensor(DobissEntity):
 
 
 class DobissTempSensor(DobissSensor):
-    """ a dobiss Temperature Sensor """
+    """a dobiss Temperature Sensor"""
 
     def __init__(self, dobiss, data, groupname):
         super().__init__(dobiss, data, groupname)
@@ -437,11 +443,11 @@ class DobissTempSensor(DobissSensor):
 
 
 class DobissBinarySensor(DobissSensor):
-    """ a dobiss Binary Sensor """
+    """a dobiss Binary Sensor"""
 
 
 class DobissLightSensor(DobissSensor):
-    """ a dobiss Light Sensor """
+    """a dobiss Light Sensor"""
 
     def __init__(self, dobiss, data, groupname):
         super().__init__(dobiss, data, groupname)
@@ -450,7 +456,7 @@ class DobissLightSensor(DobissSensor):
 
 class DobissAPI:
     def __init__(self, secret, host, secure: bool):
-        """ Initialize dobiss api object """
+        """Initialize dobiss api object"""
         url = ""
         ws_url = ""
         if secure:
@@ -525,16 +531,31 @@ class DobissAPI:
             await self._session.close()
         return auth_ok
 
+    async def get_apikey(self):
+        """Request the API key from dobiss NXT: need to enable this in the NXT server (blue button next to API key) first"""
+        get_apikey_ok = False
+        try:
+            self.start_session()
+            async with self._session.get(self._url + "jwtsecret") as response:
+                if response and response.status == 200:
+                    apikey_data = await response.json()
+                    logger.debug(f"apikey response: {apikey_data}")
+                    self._secret = apikey_data["jwt_secret"]
+                    get_apikey_ok = True
+        except Exception:
+            logger.exception("Get APIKey Dobiss failed")
+        finally:
+            await self._session.close()
+        return get_apikey_ok
+
     def get_token(self):
-        """ Request a token to use in a request to the Dobiss server """
+        """Request a token to use in a request to the Dobiss server"""
         if self._exp_time < datetime.now() + timedelta(hours=20):
             # get new token
-            self._token = (
-                jwt.encode(
-                    {"name": "my_application"},
-                    self._secret,
-                    headers={"expiresIn": "24h"},
-                )
+            self._token = jwt.encode(
+                {"name": "my_application"},
+                self._secret,
+                headers={"expiresIn": "24h"},
             )
             self._exp_time = datetime.now() + timedelta(hours=20)
         return self._token
@@ -727,6 +748,13 @@ class DobissAPI:
                                     self, subject, group["group"]["name"]
                                 )
                             )
+                        # other things connected to dobiss NXT directly?? In demo there are screens etc
+                        elif str(subject["icons_id"]) == str(DOBISS_UP) or str(
+                            subject["icons_id"]
+                        ) == str(DOBISS_DOWN):
+                            new_devices.append(
+                                DobissSwitch(self, subject, group["group"]["name"])
+                            )
         for dev in new_devices:
             existing_dev = self.get_device_by_id(dev.object_id)
             if existing_dev:
@@ -747,13 +775,29 @@ class DobissAPI:
         for device in self._devices:
             if device.icons_id == DOBISS_UP:
                 # look for a corresponding buddy
-                buddyname = get_buddy_name(device.name)
-                for buddy in self._devices:
-                    if buddy.name == buddyname and buddy.icons_id == DOBISS_DOWN:
-                        # we found a buddy
-                        buddy.set_buddy(device)
-                        device.set_buddy(buddy)
-                        logger.debug(f"buddy for {device.name} found")
+                # starting from dobiss NXT 3.0, there is a lock field that points to the buddy
+                if (
+                    "settings" in device.attributes
+                    and "locks" in device.attributes["settings"]
+                    and device.attributes["settings"]["locks"] is not None
+                ):
+                    buddy_channel = device.attributes["settings"]["locks"][0]
+                    for buddy in self._devices:
+                        if (
+                            buddy._channel == buddy_channel
+                            and buddy._address == device._address
+                        ):
+                            buddy.set_buddy(device)
+                            device.set_buddy(buddy)
+                            logger.debug(f"buddy for {device.name} found")
+                if device.buddy is None:
+                    buddyname = get_buddy_name(device.name)
+                    for buddy in self._devices:
+                        if buddy.name == buddyname and buddy.icons_id == DOBISS_DOWN:
+                            # we found a buddy
+                            buddy.set_buddy(device)
+                            device.set_buddy(buddy)
+                            logger.debug(f"buddy for {device.name} found")
                 if not device._buddy:
                     logger.warn(f"No buddy for {device.name} found")
 
